==> migrate_wizard-1.0.4-alpha1.tar.gz: migrate_wizard/src/Form/OriginUserRoles.php <==
<?php

namespace Drupal\migrate_wizard\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\migrate_wizard\MWConfigBuilder;
use Drupal\migrate_wizard\MWManageDataService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure migrate_wizard.
 */
class OriginUserRoles extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected $mwManageDataService;

  /**
   * {@inheritdoc}
   */
  protected $mwConfigBuilder;

  /**
   * {@inheritdoc}
   */
  protected $roles;

  /**
   * {@inheritdoc}
   */
  protected $config;

  /**
   * {@inheritdoc}
   */
  protected $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  public function __construct(MWManageDataService $mw_manage_data_service, MWConfigBuilder $mw_config_builder, ConfigFactoryInterface $configFactory, EntityTypeManagerInterface $entity_type_manager) {
    $this->mwManageDataService = $mw_manage_data_service;
    $this->mwConfigBuilder = $mw_config_builder;
    $this->config = $configFactory->getEditable('migrate_wizard.settings');
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new self(
      $container->get('migrate_wizard.migrate_wizard_manage_data_service'),
      $container->get('migrate_wizard.migrate_wizard_config_builder_service'),
      $container->get('config.factory'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'manage_origin_node_fields';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['migrate_wizard.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $current_config = $this->config->get('origin_user_roles');

    $this->roles = $this->mwManageDataService->getOriginRoles();

    $current_roles = $this->entityTypeManager->getStorage('user_role')->loadMultiple();
    $current_roles_array = [
      'none' => t('Do not migrate'),
      'create' => t('Create Rol'),
    ];
    foreach ($current_roles as $current_role) {
      $current_roles_array[$current_role->id()] = $current_role->label();
    }

    foreach ($this->roles as $key_origin_role => $origin_role) {
      $current_value = 'none';
      if ($current_config) {
        $current_value = $current_config['roles'][$key_origin_role];
      }
      $form['roles'][$key_origin_role] = [
        '#type' => 'select',
        '#title' => $origin_role,
        '#options' => $current_roles_array,
        '#validated' => TRUE,
        '#value' => $current_value,
      ];
    }

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {}

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $user_inputs = $form_state->getUserInput();
    $array_config = [];
    foreach ($this->roles as $key_rol => $rol) {
      $array_config['roles'][$key_rol] = [
        'origin' => $this->roles[$key_rol],
        'destiny' => $user_inputs[$key_rol],
      ];
    }
    $this->config->set('origin_user_roles', $array_config)->save();
    $this->mwManageDataService->createRoles($array_config);

  }

}

==> migrate_wizard-1.0.19-alpha1.tar.gz: migrate_wizard/src/Form/OriginUserRoles.php <==
<?php

namespace Drupal\migrate_wizard\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\migrate_wizard\MWConfigBuilder;
use Drupal\migrate_wizard\MWManageDataService;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Configure migrate_wizard.
 */
class OriginUserRoles extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected $mwManageDataService;

  /**
   * {@inheritdoc}
   */
  protected $mwConfigBuilder;

  /**
   * {@inheritdoc}
   */
  protected $roles;

  /**
   * {@inheritdoc}
   */
  protected $config;

  /**
   * {@inheritdoc}
   */
  protected $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  public function __construct(MWManageDataService $mw_manage_data_service, MWConfigBuilder $mw_config_builder, ConfigFactoryInterface $configFactory, EntityTypeManagerInterface $entity_type_manager) {
    $this->mwManageDataService = $mw_manage_data_service;
    $this->mwConfigBuilder = $mw_config_builder;
    $this->config = $configFactory->getEditable('migrate_wizard.settings');
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new self(
      $container->get('migrate_wizard.migrate_wizard_manage_data_service'),
      $container->get('migrate_wizard.migrate_wizard_config_builder_service'),
      $container->get('config.factory'),
      $container->get('entity_type.manager')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'manage_origin_node_fields';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['migrate_wizard.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {

    $current_config = $this->config->get('origin_user_roles');

    $this->roles = $this->mwManageDataService->getOriginRoles();

    $current_roles = $this->entityTypeManager->getStorage('user_role')->loadMultiple();
    $current_roles_array = [
      'none' => t('Do not migrate'),
      'create' => t('Create Rol'),
    ];
    foreach ($current_roles as $current_role) {
      $current_roles_array[$current_role->id()] = $current_role->label();
    }

    foreach ($this->roles as $key_origin_role => $origin_role) {
      $current_value = 'none';
      if ($current_config && isset($current_config['roles'][$key_origin_role]['destiny'])) {
        $current_value = $current_config['roles'][$key_origin_role]['destiny'];
      }
      $form['roles'][$key_origin_role] = [
        '#type' => 'select',
        '#title' => $origin_role,
        '#options' => $current_roles_array,
        '#validated' => TRUE,
        '#value' => $current_value,
      ];
    }

    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save'),
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {}

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $user_inputs = $form_state->getUserInput();
    $array_config = [];
    foreach ($this->roles as $key_rol => $rol) {
      $array_config['roles'][$key_rol] = [
        'origin' => $this->roles[$key_rol],
        'destiny' => $user_inputs[$key_rol],
      ];
    }
    $this->config->set('origin_user_roles', $array_config)->save();
    $this->mwManageDataService->createRoles($array_config);
  }
}
